@@ -6,8 +6,8 @@ __all__ = [
 
 __author__ = "Jeff Hui"
 __author_email__ = "jeff@jeffhui.net"
-__copyright__ = "Copyright 2012, Jeff Hui"
-__credits__ = ["Jeff Hui", "Patrice Neff"]
+__copyright__ = "Copyright 2013, Jeff Hui"
+__credits__ = ["Jeff Hui", "Patrice Neff", "Andrew Lee"]
 
 __license__ = "MIT"
-__version__ = "0.2.6"
+__version__ = "0.2.8"
