@@ -8,6 +8,7 @@ from base import BaseScanner
 import os
 import fsevents
 import time
+import sys
 
 class FSEventsScanner(BaseScanner):
     """
@@ -16,13 +17,14 @@ class FSEventsScanner(BaseScanner):
     def __init__(self, *args, **kwargs):
         super(FSEventsScanner, self).__init__(*args, **kwargs)
         self._observer = self._generate_observer()
+        self._stream = None
 
     def _generate_observer(self):
         observer = fsevents.Observer()
         # use file_events=True to mimic other implementations
         for path in self.paths:
-            stream = fsevents.Stream(self._callback, path, file_events=True)
-            observer.schedule(stream)
+            self._stream = fsevents.Stream(self._callback, path, file_events=True)
+            observer.schedule(self._stream)
         return observer
 
     def loop(self, sleep_time=None):
@@ -42,7 +44,6 @@ class FSEventsScanner(BaseScanner):
         # that we just want to escape without problems.
         #
         # So we're silently absorbing all the errors
-        import sys
         try:
             from cStringIO import StringIO
         except:
@@ -50,6 +51,7 @@ class FSEventsScanner(BaseScanner):
         old_err, old_out = sys.stderr, sys.stdout
         sys.stderr, sys.stdout = StringIO(), StringIO()
 
+        self._observer.unschedule(self._stream)
         self._observer.stop()
 
         sys.stderr, sys.stdout = old_err, old_out
